@@ -2,9 +2,10 @@
 
 from .crackers.cloudflare import CloudFlareCracker
 from .crackers.incapsula import IncapsulaCracker
+from .crackers.hcaptcha import HcaptchaCracker
 from .crackers.recaptcha import ReCaptchaUniversalCracker, ReCaptchaEnterpriseCracker, ReCaptchaSteamCracker
 
 __all__ = [
-    'pynocaptcha', 'CloudFlareCracker', 'IncapsulaCracker', 
+    'pynocaptcha', 'CloudFlareCracker', 'IncapsulaCracker', 'HcaptchaCracker', 
     'ReCaptchaUniversalCracker', 'ReCaptchaEnterpriseCracker', 'ReCaptchaSteamCracker'
 ]
