@@ -21,7 +21,7 @@ class BaseCracker:
     def __init__(
         self,    
         user_token: str = None,
-        developer_token: str = "",   
+        developer_id: str = "",   
         user_agent: str = "",
         proxy: str = None, 
         timeout: int = 30,
@@ -33,7 +33,7 @@ class BaseCracker:
     ) -> None:
         """
         :param user_token: nocaptcha.io 用户 token
-        :param developer_token: nocaptcha.io 用户上级代理 token
+        :param developer_id: nocaptcha.io 用户上级代理 token
         :param user_agent: 请求流程使用 ua
         :param proxy: 请求流程代理, 不传默认使用系统代理, 某些强制要求代理一致或者特定区域的站点请传代理, 支持协议 http/https/socks5, 代理格式: {protocol}://{ip}:{port}（如有账号验证：{protocol}://{user}:{password}@{ip}:{port}）
         :param timeout: 破解接口超时时间(秒)
@@ -45,7 +45,7 @@ class BaseCracker:
         self.user_token = user_token
         if not self.user_token:
             raise Exception("缺少用户凭证")
-        self.developer_token = developer_token
+        self.developer_id = developer_id
         self.user_agent = user_agent
         self.proxy = proxy
         self.timeout = timeout
@@ -80,8 +80,8 @@ class BaseCracker:
         headers = {
             "User-Token": self.user_token
         }
-        if self.developer_token:
-            headers["Developer-Token"] = self.developer_token
+        if self.developer_id:
+            headers["Developer-Id"] = self.developer_id
         resp = requests.post(f"http://api.nocaptcha.io/api/wanda/{self.cracker_name}/{self.cracker_version}", headers=headers, json={
             **self.wanda_args,
             "user_agent": self.user_agent,
